InstallOptions

Struct InstallOptions 

pub struct InstallOptions {
    pub no_cache: bool,
    pub quiet: bool,
    pub backend: Backend,
    pub lockfile_only: bool,
    pub offline: bool,
    pub strict_lockfile: bool,
    pub from_lockfile: bool,
    pub native_only: bool,
    pub no_scripts: bool,
    pub script_allowlist: Option<HashSet<String>>,
}

Fields

no_cache: boolquiet: boolbackend: Backendlockfile_only: booloffline: boolstrict_lockfile: boolfrom_lockfile: bool

When true, specs came from lockfile; skip npm show and use tarball URLs only (no packument).

native_only: bool

When true, never call Bun/npm; fail with clear error if native install fails.

no_scripts: bool

When true, skip lifecycle scripts in backend fallback paths.

script_allowlist: Option<HashSet<String>>

Optional allowlist for packages allowed to run scripts in backend fallback mode.